@@ -156,7 +156,7 @@ public class MailCto {
         List<AttachmentCto> attachments = ListUtil.map(mail.getParts(), partMapFunction);
         body = getBodyOrNull(attachments);
         bodyType = getBodyTypeOrNull(attachments);
-        hasAttachment = mail.getHasAttachments() == Boolean.TRUE ? Boolean.TRUE : null;
+        hasAttachment = Boolean.TRUE.equals(mail.getHasAttachments()) ? Boolean.TRUE : null;
         realAttachment = hasAttachment;
         this.attachments = getAttachmentListWithoutBodyOrNull(attachments);
     }
