@@ -99,10 +99,8 @@ public class ConfigService {
         capabilities.addAll(remoteCapabilities);
         capabilities.add(new Capability("facade_accounts_sync"));
         capabilities.add(new Capability("facade_accounts_crud"));
-        if (sessionData.getConfiguration().isReturnNonPrimaryAccounts()) {
-            if (userHasMultipleAccountsEnabled(capabilities)) {
-                capabilities.add(new Capability("facade_multiple_accounts_enabled"));
-            }
+        if (sessionData.getConfiguration().isReturnNonPrimaryAccounts() && userHasMultipleAccountsEnabled(capabilities)) {
+            capabilities.add(new Capability("facade_multiple_accounts_enabled"));
         }
         return capabilities;
     }
